@@ -1,4 +1,4 @@
-from fastapi_plus.model.base import *
+from bztt_fastapi_plus1.model.base import *
 
 
 class Demo(Base):
