@@ -3,6 +3,16 @@ from fastapi import Header
 from .redis import RedisUtils
 from .my_jwt import my_jwt
 
+class AuthConfig(object):
+    """
+    RedisConfig Redis配置类
+    :version: 1.2
+    :date: 2020-02-11
+    """
+
+    SECRET_KEY = ""
+
+
 async def get_auth_data(authorization: str = Header(None)):
     """
     获取登录用户认证数据, 通常用于controller层
@@ -35,15 +45,19 @@ def get_auth_data_by_token(token: str, ex: int = None):
     """
 
     payload = {}
-    my_jwt1 = my_jwt()
+    my_jwt1 = my_jwt(AuthConfig.SECRET_KEY)
+
     try:
         payload, msg = my_jwt1.validate_token(token)
     except:
-        print("鉴权失败")
         pass
 
     return payload
 
+#鉴权
+def auth_pr():
+    print("鉴权")
+
 
 def update_auth_data(auth_data: dict, ex: int = None):
     """
